<?php

/**
 * @file
 * Admin page callbacks for the currency_converter module.
 */
 
 /**
 * Returns an administrative form with settings.
 */
function currency_converter_admin_settings() {
  //Get availible currencies for selected bank
  $bank = variable_get('currency_converter_bank_default', BELORUSSIAN_BANK);
  $currencies = db_result(db_query_range('SELECT data FROM {currency_converter} WHERE bank = %d', $bank, 0, 1));
  $currencies = unserialize($currencies);

  //Get array with default currency weight
  $default_weight = array();
  $default_weight['BYR'] = 0;
  $weight_index = 1;
  foreach ($currencies as $currency) {
    if ($currency['currency'] != 'BYR') {
      $default_weight[$currency['currency']] = $weight_index++;
    }
  }

  // Get current currency weights
  $weight = variable_get('currency_converter_weight', $default_weight);
  // Get default currency
  $default_currency = variable_get('currency_converter_main_currency', 'BYR');

  // Create currencies array where first currency is default currency
  $currencies = array();
  $currencies[] = $default_currency;
  foreach ($weight as $currency => $value) {
    if ($currency != $default_currency) {
      $currencies[] = $currency;
    }
  }
  
  $form['currency_converter_weight'] = array('#type' => 'checkboxes');
  
  foreach ($currencies as $currency) {
    $form[$currency]['title'] = array(
      '#value' => $currency
    );
    $form['currency_converter_weight'][$currency] = array(
      '#type' => 'weight',
      '#weight' => $weight[$currency],
      '#attributes' => array('class' => 'currency-converter-weight'),
    );
    $options[$currency] = '';
  }

  $form['currency_converter_main_currency'] = array(
    '#type' => 'radios', 
    '#default_value' => variable_get('currency_converter_main_currency', 'BYR'),
    '#options' => $options,
  );
  $form['currency_converter_currency_types'] = array(
    '#type' => 'checkboxes', 
    '#default_value' => variable_get('currency_converter_currency_types', array('BYR', 'RUB', 'EUR', 'USD', 'CAD', 'PLN', 'UAH', 'CNY', 'LTL', 'LVL')),
    '#options' => $options,
  );
  
  // Bank settings
  $form['currency_converter_bank'] = array(
    '#type' => 'fieldset',
    '#title' => t('Bank settings'),
  );
  $form['currency_converter_bank']['currency_converter_bank_default'] = array(
    '#type' => 'radios',
    '#title' => t('Select bank from currencies will be taken'),
    '#default_value' => variable_get('currency_converter_bank_default', BELORUSSIAN_BANK),
    '#options' => array(
      BELORUSSIAN_BANK => t('National Bank of Belarus'),
      RUSSIAN_BANK     => t('Russian Central Bank'),
    ),
  );
  $form['currency_converter_bank']['currency_converter_update_freq'] = array(
    '#type' => 'select',
    '#title' => t('How often update currencies rate'),
    '#options' => array(
      21600   => t('Every 6 hours'),
      86400   => t('Every day'),
      259200  => t('Every three days'),
      604800  => t('Every week'),
      2592000 => t('Every month'),
      0       => t('Never')
    ),
    '#default_value' => variable_get('currency_converter_update_freq', 86400),
  );
  
  // Style settings
  $form['currency_converter_css'] = array(
    '#type' => 'fieldset',
    '#title' => t('Css settings'),
  );
  $form['currency_converter_css'] ['currency_converter_use_css'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use module css'),
    '#default_value' => variable_get('currency_converter_use_css', 1),
    '#description' => t('If checked, block will use module css'),
  );
  $form['currency_converter_css'] ['currency_converter_use_bg'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use module background'),
    '#default_value' => variable_get('currency_converter_use_bg', 1),
    '#description' => t('If checked, block will use module background'),
  );

  // Submitters
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
  $form['update_rates'] = array(
    '#type' => 'submit',
    '#value' => t('Update exchange rates'),
  );  
  return $form;
}

function currency_converter_admin_settings_submit($form, &$form_state) {
  $values = $form_state['values'];

  if ($values['currency_converter_weight']['BYR']) {
    variable_set('currency_converter_weight', $values['currency_converter_weight']);
  }

  variable_set('currency_converter_main_currency' , $values['currency_converter_main_currency']);
  variable_set('currency_converter_currency_types', $values['currency_converter_currency_types']);
  variable_set('currency_converter_bank_default'  , $values['currency_converter_bank_default']);
  variable_get('currency_converter_update_freq'   , $values['currency_converter_update_freq']);
  variable_set('currency_converter_use_css'       , $values['currency_converter_use_css']);
  variable_set('currency_converter_use_bg'        , $values['currency_converter_use_bg']);
  
  if ($values['op'] == $values['update_rates']) {
    _currency_conterter_update_currencies() 
  }
  drupal_set_message(t('Configuration saved'));
}

function theme_currency_converter_admin_settings($form) { 
  foreach (element_children($form) as $key) {
    if (drupal_strlen($key) == 3) {
      $row = array();
      $row[] = drupal_render($form['currency_converter_currency_types'][$key]);
      $row[] = drupal_render($form[$key]['title']);
      $row[] = drupal_render($form['currency_converter_weight'][$key]);
      $row[] = drupal_render($form['currency_converter_main_currency'][$key]);
      $rows[] = array(
        'data' => $row,
        'class' => 'draggable',
      );
    }
  }    
  $header = array(t('Enabled'), t('Currency'), t('Weight'), t('Set as default'));
  $output = theme('table', $header, $rows, array('id' => 'currency-converter-table'));  
  drupal_add_tabledrag('currency-converter-table', 'order', 'sibling', 'currency-converter-weight');  
  return $output . drupal_render($form);
}
